pm4py.algo.enhancement.resource\_profiles package
=================================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.enhancement.resource_profiles.variants

Submodules
----------

pm4py.algo.enhancement.resource\_profiles.algorithm module
----------------------------------------------------------

.. automodule:: pm4py.algo.enhancement.resource_profiles.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.enhancement.resource_profiles
   :members:
   :undoc-members:
   :show-inheritance:
